@@ -20,7 +20,7 @@ package
 package PkgConfig;
 
 #First two digits are Perl version, second two are pkg-config version
-our $VERSION = '0.08626';
+our $VERSION = '0.08826';
 
 use strict;
 use warnings;
@@ -80,6 +80,13 @@ if($ENV{PKG_CONFIG_NO_OS_CUSTOMIZATION}) {
 
     @DEFAULT_SEARCH_PATH = split $Config{path_sep}, $ENV{PKG_CONFIG_LIBDIR};
 
+} elsif($^O eq 'solaris' && $Config{ptrsize} == 8) {
+
+    @DEFAULT_SEARCH_PATH = qw(
+        /usr/local/lib/64/pkgconfig /usr/local/share/pkgconfig
+        /usr/lib/64/pkgconfig /usr/share/pkgconfig
+    );
+
 } elsif($^O =~ /^(gnukfreebsd|linux)$/ && -r "/etc/debian_version") {
 
     my $arch;
